EM algorithm used in the mixture cure model by assuming a latent indicator of uncure status. Detailed estimation methods can be found in the reference section.
em(Time, Status, X, Z, offsetvar, b, beta, model, link, emmax, eps)time to event of interest
censoring indicator, 1=event of interest happens, and 0=censoring
a vector or matrix of covariates corresponding to the latency part
a vector or matrix of covariates corresponding to the incidence part
offset variable
initial value for parameter b
initial value for parameter beta
either "ph" or "aft"
specifies the link in incidence part. The "logit", "probit" or complementary loglog ("cloglog") links are available. By default link = "logit".
specifies the maximum iteration number. If the convergence criterion is not met, the EM iteration will be stopped after emmax iterations and the estimates will be based on the last maximum likelihood iteration. The default emmax = 100.
sets the convergence criterion. The default is eps = 1e-7. The iterations are considered to be converged when the maximum relative change in the parameters and likelihood estimates between iterations is less than the value specified.