Learn R Programming

smcure (version 2.0)

predictsmcure: prediction of semicure model

Description

Prediction of survival probability from the smcure in order to pass subjects to plotpredictsmcure().

Usage

predictsmcure(object, newX, newZ, model = c("ph", "aft"), ...)

Arguments

object

an object of smcure

newX

new value(s) of X

newZ

new value(s) of Z

model

either 'ph' or 'aft'

further arguments to be passed to the predictsmcure function

Details

Predicted population survival function can be calculated by the following equation $$\hat S_{pop}(t)=\hat \pi+(1-\hat \pi)\hat S(t) $$ where \(\hat S(t)\) is the estimated survival function for the uncured patients based on the PH or AFT model.

See Also

smcure, printsmcure, plotpredictsmcure