Learn R Programming

smcure (version 2.0)

smcure-package: Semiparametric mixture cure model

Description

An R package to fit semiparametric PH mixture cure model or AFT mixture cure model

Arguments

Details

Package: smcure
Type: Package
Version: 2.0
Date: 2012-02-05
License: GPL-2
LazyLoad: yes

References

Kersey, et al., Comparison of autologous and allogeneic bone marrow trans-plantation for treatment of high-risk refractory acute lymphoblastic leukemia. New England Journal of Medicine, 317 (8), 461-467, 1987.

Kirkwood, et al., Interferon alfa-2b adjuvant therapy of high-risk resected cutaneous melanoma: the eastern cooperative oncology group trial est 1684. Journal of Clinical Oncology, 14 (1), 7, 1996.

J. Zhang and Y. Peng. A new estimation method for the semiparametric accelerated failure time mixture cure model. Statistics in Medicine, 26(16):3157-3171, 2007.

Peng, Y., Dear, K. B. G., 2000. A nonparametric mixture model for cure rate estimation. Biometrics 56 (1), 237-243.

C. Cai, et al., smcure: An R-Package for estimating semiparametric mixture cure models, Computer Methods and Programs in Biomedicine. (2012), http://dx.doi.org/10.1016/j.cmpb.2012.08.013.