Learn R Programming

smcure (version 2.0)

smsurv: Estimation of the baseline survival

Description

The estimated baseline survival function based on the Breslow method, which is used in order to update the E-step in the EM algorithm.

Usage

smsurv(Time, Status, X, beta, w, model)

Arguments

Time

this is the follow up time for "ph" model. If model is "aft", then this is residual \(\log t-\bm{\beta} \mathbf x\).

Status

censoring indicator, 1=event of interest happens, and 0=censoring

X

effects of covariates of uncured patients

beta

initial beta from coxph

w

conditional probability of the ith individual remains uncured at the mth iteration. We use Status as initial value

model

specifies your model, it can be "ph" or "aft"