Prediction of survival probability from the smcure in order to pass subjects to plotpredictsmcure().
predictsmcure(object, newX, newZ, model = c("ph", "aft"), ...)an object of smcure
new value(s) of X
new value(s) of Z
either 'ph' or 'aft'
further arguments to be passed to the predictsmcure function
Predicted population survival function can be calculated by the following equation $$\hat S_{pop}(t)=\hat \pi+(1-\hat \pi)\hat S(t) $$ where \(\hat S(t)\) is the estimated survival function for the uncured patients based on the PH or AFT model.
smcure, printsmcure, plotpredictsmcure