The estimated baseline survival function based on the Breslow method, which is used in order to update the E-step in the EM algorithm.
smsurv(Time, Status, X, beta, w, model)this is the follow up time for "ph" model. If model is "aft", then this is residual \(\log t-\bm{\beta} \mathbf x\).
censoring indicator, 1=event of interest happens, and 0=censoring
effects of covariates of uncured patients
initial beta from coxph
conditional probability of the ith individual remains uncured at the mth iteration. We use Status as initial value
specifies your model, it can be "ph" or "aft"